@@ -50,8 +50,41 @@ class PrSpiders(settions):
                         for i in range(0, len(cls.start_urls), cls.download_num)]
         for u in url_dim_list:
             time.sleep(cls.download_delay)
-            cls.SpiderPool(callback=cls.parse,
-                           url=u, **kwargs)
+            cls.Requests(callback=cls.parse,
+                         url=u, **kwargs)
+
+    @classmethod
+    def RequestsMap(cls, request=None, callback=None, headers=None, retry_time=3, method='GET', meta=None,
+                    encoding='utf-8', retry_interval=1, timeout=10, **kwargs):
+        futures = []
+        if isinstance(request, str):
+            raise AttributeError(
+                "Requests object must be list")
+        else:
+            url_dim_list = [request[i:i + cls.download_num]
+                            for i in range(0, len(request), cls.download_num)]
+            for u in url_dim_list:
+                time.sleep(cls.download_delay)
+                for _u in u:
+                    url = _u.get('url')
+                    data = _u.get('data', None)
+                    params = _u.get('params', None)
+                    meta = _u.get('meta', None)
+                    kwargs.update({"data": data})
+                    kwargs.update({"params": params})
+                    futures.append(
+                        ThreadPoolExecutor(cls.workers).submit(cls.fetch, url=url, callback=callback, headers=headers,
+                                                               timeout=timeout,
+                                                               retry_time=retry_time,
+                                                               method=method, meta=meta, encoding=encoding,
+                                                               retry_interval=retry_interval, **kwargs))
+
+                for future in as_completed(futures):
+                    worker_exception = future.exception()
+                    if worker_exception:
+                        current_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+                        logging.exception(
+                            f'{current_time} [PrSpider Exception] %s' % worker_exception)
 
     @classmethod
     def Requests(cls, url=None, callback=None, headers=None, retry_time=3, method='GET', meta=None,
@@ -66,7 +99,8 @@ class PrSpiders(settions):
                 time.sleep(cls.download_delay)
                 for _u in u:
                     futures.append(
-                        ThreadPoolExecutor(cls.workers).submit(cls.fetch, url=_u, callback=callback, headers=headers, timeout=timeout,
+                        ThreadPoolExecutor(cls.workers).submit(cls.fetch, url=_u, callback=callback, headers=headers,
+                                                               timeout=timeout,
                                                                retry_time=retry_time,
                                                                method=method, meta=meta, encoding=encoding,
                                                                retry_interval=retry_interval, **kwargs))
@@ -84,21 +118,6 @@ class PrSpiders(settions):
                 logging.exception(
                     f'{current_time} [PrSpider Exception] %s' % worker_exception)
 
-    @classmethod
-    def SpiderPool(cls, callback=None, url=None, **kwargs):
-        futures = []
-        if isinstance(url, str):
-            url = [url]
-        for _url in url:
-            futures.append(
-                ThreadPoolExecutor(cls.workers).submit(cls.fetch, url=_url, callback=callback, **kwargs))
-        for future in as_completed(futures):
-            worker_exception = future.exception()
-            if worker_exception:
-                current_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-                logging.exception(
-                    f'{current_time} [PrSpider Exception] %s' % worker_exception)
-
     @classmethod
     def fetch(self, url, callback, headers=None, retry_time=3, method='GET', meta=None,
               encoding='utf-8', retry_interval=1, timeout=3, **kwargs):
@@ -106,15 +125,15 @@ class PrSpiders(settions):
         current_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
         time.sleep(self.download_delay)
         response = prequest().get(url, headers=headers, retry_time=retry_time, method=method, meta=meta,
-                                      encoding=encoding, retry_interval=retry_interval, timeout=timeout,
-                                      settion=settions, **kwargs, )
+                                  encoding=encoding, retry_interval=retry_interval, timeout=timeout,
+                                  settion=settions, **kwargs)
         if response:
             if response.ok:
                 settions.success_num += 1
                 logging.info(
                     f'{current_time} [PrSpider] True [Method] {method} [Status] {response.code} [Url] {url}')
-                callback(response)
-                return self
+            callback(response)
+            return self
         else:
             settions.false_num += 1
             if response:
